@@ -19,24 +19,23 @@ except ImportError:
     import importlib_resources
 
 
-import mistune
-import pygments
 import networkx as nx
 from tqdm.auto import tqdm
 from jinja2 import Template
+import mistune
 
 from ploomber.Table import Table, TaskReport, BuildReport
 from ploomber.products import MetaProduct
 from ploomber.util import (image_bytes2html, isiterable, path2fig, requires,
                            markup)
-from ploomber.CodeDiffer import CodeDiffer
 from ploomber import resources
 from ploomber import executors
 from ploomber.constants import TaskStatus, DAGStatus
 from ploomber.exceptions import DAGBuildError, DAGRenderError
-from ploomber.ExceptionCollector import ExceptionCollector
+from ploomber.MessageCollector import MessageCollector
 from ploomber.util.util import callback_check
 from ploomber.dag.DAGConfiguration import DAGConfiguration
+from ploomber.dag.DAGLogger import DAGLogger
 
 
 class DAG(collections.abc.Mapping):
@@ -58,12 +57,11 @@ class DAG(collections.abc.Mapping):
         or 'parallel') the corresponding executor is initialized with default
         parameters
     """
-    def __init__(self, name=None, clients=None, differ=None,
-                 executor='serial'):
+
+    def __init__(self, name=None, clients=None, executor='serial'):
         self._G = nx.DiGraph()
 
         self.name = name or 'No name'
-        self.differ = differ or CodeDiffer()
         self._logger = logging.getLogger(__name__)
 
         self._clients = clients or {}
@@ -86,7 +84,10 @@ class DAG(collections.abc.Mapping):
         self.on_failure = None
         self._available_callback_kwargs = {'dag': self}
 
-        self._cfg = DAGConfiguration.default()
+        self._params = DAGConfiguration()
+
+        # task access differ using .dag.differ
+        self.differ = self._params.differ
 
     @property
     def _exec_status(self):
@@ -225,6 +226,17 @@ class DAG(collections.abc.Mapping):
             A dict-like object with tasks as keys and dicts with task
             status as values
         """
+        kwargs = callback_check(self._params.logging_handler_factory,
+                                available={'dag_name': self.name})
+
+        dag_logger = DAGLogger(self._params.logging_handler_factory(**kwargs))
+
+        with dag_logger:
+            report = self._build(force, show_progress)
+
+        return report
+
+    def _build(self, force, show_progress):
         if self._exec_status == DAGStatus.ErroredRender:
             raise DAGBuildError('Cannot build dag that failed to render, '
                                 'fix rendering errors then build again. '
@@ -352,10 +364,6 @@ class DAG(collections.abc.Mapping):
         out = Template(template_md).render(plot=plot, status=status, dag=self)
 
         if fmt == 'html':
-            if not mistune or not pygments:
-                raise ImportError('mistune and pygments are '
-                                  'required to export to HTML')
-
             renderer = markup.HighlightRenderer()
             out = mistune.markdown(out, escape=False, renderer=renderer)
 
@@ -363,6 +371,7 @@ class DAG(collections.abc.Mapping):
             html = importlib_resources.read_text(resources,
                                                  'github-markdown.html')
             out = Template(html).render(content=out)
+
         if path is not None:
             Path(path).write_text(out)
 
@@ -406,14 +415,14 @@ class DAG(collections.abc.Mapping):
         """
         Render tasks, and update exec_status
         """
-        if not self._cfg.cache_rendered_status or not self._did_render:
+        if not self._params.cache_rendered_status or not self._did_render:
             self._logger.info('Rendering DAG %s', self)
 
             if show_progress:
                 tasks = tqdm(self.values(), total=len(self))
 
-            exceptions = ExceptionCollector()
-            warnings_ = None
+            exceptions = MessageCollector()
+            warnings_ = MessageCollector()
 
             for t in tasks:
                 # no need to process task with AbortedRender
@@ -424,13 +433,24 @@ class DAG(collections.abc.Mapping):
                     tasks.set_description('Rendering DAG "{}"'
                                           .format(self.name))
 
-                with warnings.catch_warnings(record=True) as warnings_:
+                with warnings.catch_warnings(record=True) as warnings_current:
                     try:
                         t.render(force=force,
-                                 outdated_by_code=self._cfg.outdated_by_code)
+                                 outdated_by_code=self._params.outdated_by_code)
                     except Exception:
                         tr = traceback.format_exc()
-                        exceptions.append(traceback_str=tr, task_str=repr(t))
+                        exceptions.append(message=tr, task_str=repr(t))
+
+                if warnings_current:
+                    w = [str(a_warning.message) for a_warning
+                         in warnings_current]
+                    warnings_.append(task_str=t.name,
+                                     message='\n'.join(w))
+
+            if warnings_:
+                # FIXME: maybe raise one by one to keep the warning type
+                warnings.warn('Some tasks had warnings when rendering DAG '
+                              '"{}":\n{}'.format(self.name, str(warnings_)))
 
             if exceptions:
                 self._exec_status = DAGStatus.ErroredRender
@@ -440,14 +460,6 @@ class DAG(collections.abc.Mapping):
                                      'rendering):\n{}'
                                      .format(str(exceptions)))
 
-            # TODO: also include warnings in the exception message
-            if warnings_:
-                # maybe raise one by one to keep the warning type
-                messages = [str(w.message) for w in warnings_]
-                warning = ('Task "{}" had the following warnings:\n\n{}'
-                           .format(repr(t), '\n'.join(messages)))
-                warnings.warn(warning)
-
         self._exec_status = DAGStatus.WaitingExecution
 
     def _add_task(self, task):
