@@ -16,6 +16,12 @@ class TaskBuildError(Exception):
     pass
 
 
+class TaskRenderError(Exception):
+    """Raise when a task fails to render
+    """
+    pass
+
+
 class RenderError(Exception):
     """Raise when a template fails to render
     """
@@ -31,3 +37,4 @@ class SourceInitializationError(Exception):
 class CallbackSignatureError(Exception):
     """When a callback function does not have the right signature
     """
+    pass
