@@ -1,15 +1,15 @@
 """
 Serial DAG executor: builds one task at a time
 """
+import warnings
 from multiprocessing import Pool
 import traceback
 import logging
 
 from tqdm.auto import tqdm
 from ploomber.executors.Executor import Executor
-from ploomber.executors.LoggerHandler import LoggerHandler
 from ploomber.exceptions import DAGBuildError
-from ploomber.ExceptionCollector import ExceptionCollector
+from ploomber.MessageCollector import MessageCollector
 from ploomber.constants import TaskStatus
 
 
@@ -17,28 +17,35 @@ from ploomber.constants import TaskStatus
 
 
 class Serial(Executor):
-    """Runs a DAG serially
+    """Runs a DAG one task at a time
+
+    Tries to run as many tasks as possible (even if some of them fail), when
+    tasks fail, a final traceback is shown at the end of the execution showing
+    error messages along with their corresponding task to ease debgging, the
+    same happens with warnings: they are captured and shown at the end of the
+    execution (but only when build_in_subprocess is False).
+
+    Parameters
+    ----------
+    build_in_subprocess : bool, optional
+        Determines whether tasks should be executed in a subprocess or in the
+        current process. For pipelines with a lot of PythonCallables loading
+        large objects such as pandas.DataFrame, this option is recommended as
+        it guarantees that memory will be cleared up upon task execution.
+        Defaults to True
 
     """
     # TODO: maybe add a parameter: stop on first exception, same for Parallel
 
-    def __init__(self, logging_directory=None, logging_level=logging.INFO,
-                 execute_callables_in_subprocess=True):
-        self.logging_directory = logging_directory
-        self.logging_level = logging_level
+    def __init__(self, build_in_subprocess=True):
         self._logger = logging.getLogger(__name__)
-        self._execute_callables_in_subprocess = execute_callables_in_subprocess
+        self._build_in_subprocess = build_in_subprocess
 
     def __call__(self, dag, show_progress, task_kwargs):
         super().__call__(dag)
 
-        if self.logging_directory:
-            logger_handler = LoggerHandler(dag_name=dag.name,
-                                           directory=self.logging_directory,
-                                           logging_level=self.logging_level)
-            logger_handler.add()
-
-        exceptions = ExceptionCollector()
+        exceptions = MessageCollector()
+        warnings_ = MessageCollector()
         task_reports = []
 
         if show_progress:
@@ -54,16 +61,17 @@ class Serial(Executor):
                 tasks.set_description('Building task "{}"'.format(t.name))
 
             try:
-                if (callable(t.source.value)
-                        and self._execute_callables_in_subprocess):
-                    report = execute_in_subprocess(t, task_kwargs)
-                else:
-                    report = t.build(**task_kwargs)
+                with warnings.catch_warnings(record=True) as warnings_current:
+                    if (callable(t.source.value)
+                            and self._build_in_subprocess):
+                        report = execute_in_subprocess(t, task_kwargs)
+                    else:
+                        report = t.build(**task_kwargs)
             except Exception:
                 t.exec_status = TaskStatus.Errored
                 new_status = TaskStatus.Errored
                 tr = traceback.format_exc()
-                exceptions.append(traceback_str=tr, task_str=repr(t))
+                exceptions.append(message=tr, task_str=repr(t))
             else:
                 new_status = TaskStatus.Executed
 
@@ -71,10 +79,23 @@ class Serial(Executor):
                     t.exec_status = new_status
                 except Exception:
                     tr = traceback.format_exc()
-                    exceptions.append(traceback_str=tr, task_str=repr(t))
+                    exceptions.append(message=tr, task_str=repr(t))
 
                 task_reports.append(report)
 
+            if warnings_current:
+                w = [str(a_warning.message) for a_warning
+                     in warnings_current]
+                warnings_.append(task_str=t.name,
+                                 message='\n'.join(w))
+
+        # end of for loop
+
+        if warnings_:
+            # FIXME: maybe raise one by one to keep the warning type
+            warnings.warn('Some tasks had warnings when rendering DAG '
+                          '"{}":\n{}'.format(dag.name, str(warnings_)))
+
         if exceptions:
             raise DAGBuildError('DAG build failed, the following '
                                 'tasks crashed '
@@ -82,13 +103,10 @@ class Serial(Executor):
                                 'execution):\n{}'
                                 .format(str(exceptions)))
 
-        if self.logging_directory:
-            logger_handler.remove()
-
         # only close when tasks are executed in this process (otherwise
         # this won't have any effect anyway)
-        if not self._execute_callables_in_subprocess:
-            for client in self.clients.values():
+        if not self._build_in_subprocess:
+            for client in dag.clients.values():
                 client.close()
 
         return task_reports
