@@ -54,11 +54,53 @@ class Product(abc.ABC):
         """
         self._identifier.render(params, **kwargs)
 
-    def _outdated(self):
-        return (self._outdated_data_dependencies()
-                or self._outdated_code_dependency())
+    def _is_outdated(self, outdated_by_code=True):
+        """
+        Given current conditions, determine if the Task that holds this
+        Product should be executed
+
+        Returns
+        -------
+        bool
+            True if the Task should execute
+        """
+        run = False
+
+        self.logger.info('Checking status for task "%s"', self.task.name)
+
+        # check product...
+        p_exists = self.exists()
+
+        # check dependencies only if the product exists
+        if p_exists:
+
+            if self._outdated_data_dependencies():
+                run = True
+                self.logger.info('Outdated data deps...')
+            else:
+                self.logger.info('Up-to-date data deps...')
+
+            if outdated_by_code:
+                if self._outdated_code_dependency():
+                    run = True
+                    self.logger.info('Outdated code dep...')
+                else:
+                    self.logger.info('Up-to-date code dep...')
+        else:
+            run = True
+
+            # just log why it will run
+            if not p_exists:
+                self.logger.info('Product does not exist...')
+
+        self.logger.info('Should run? %s', run)
+
+        return run
 
     def _outdated_data_dependencies(self):
+        """
+        Determine if the product is outdated by checking upstream timestamps
+        """
 
         if self._outdated_data_dependencies_status is not None:
             self.logger.debug(('Returning cached data dependencies status. '
@@ -76,7 +118,7 @@ class Product(abc.ABC):
                 return True
             else:
                 return ((up_prod.metadata.timestamp > self.metadata.timestamp)
-                        or up_prod._outdated())
+                        or up_prod._is_outdated())
 
         outdated = any([is_outdated(up.product) for up
                         in self.task.upstream.values()])
@@ -90,23 +132,32 @@ class Product(abc.ABC):
         return self._outdated_data_dependencies_status
 
     def _outdated_code_dependency(self):
+        """
+        Determine if the product is outdated by checking the source code that
+        it generated it
+        """
         if self._outdated_code_dependency_status is not None:
             self.logger.debug(('Returning cached code dependencies status. '
                                'Outdated? %s'),
                               self._outdated_code_dependency_status)
             return self._outdated_code_dependency_status
 
-        outdated = self.task.dag.differ.code_is_different(
+        outdated, diff = self.task.dag.differ.is_different(
             self.metadata.stored_source_code,
-            self.task.source_code,
-            language=self.task.source.language)
+            str(self.task.source),
+            extension=self.task.source.extension)
 
         self._outdated_code_dependency_status = outdated
 
-        self.logger.debug(('Finished checking code dependencies status. '
+        self.logger.debug(('Finished checking code status for task "%s" '
                            'Outdated? %s'),
+                          self.task.name,
                           self._outdated_code_dependency_status)
 
+        if outdated:
+            self.logger.info('Task "%s" has outdated code. Diff:\n%s',
+                             self.task.name, diff)
+
         return self._outdated_code_dependency_status
 
     def _clear_cached_status(self):
@@ -193,12 +244,3 @@ class Product(abc.ABC):
         """Deletes the product
         """
         pass
-
-    @property
-    @abc.abstractmethod
-    def name(self):
-        """
-        Product name, this is used as Task.name default if no name
-        is provided
-        """
-        pass
