@@ -93,6 +93,18 @@ class Task(abc.ABC):
         A read-only dictionary-like object with params passed, after running
         'product' and 'upstream' are added, if any
 
+    on_render : callable
+        Function to execute after rendering. The function can request any of
+        the following parmeters: task, client and/or product.
+
+    on_finish : callable
+        Function to execute upon execution. Can request the same params as the
+        on_render hook.
+
+    on_failure : callable
+        Function to execute upon failure. Can request the same params as the
+        on_render hook.
+
     Notes
     -----
     All subclasses must implement the same constuctor to keep the API
@@ -700,8 +712,6 @@ class Task(abc.ABC):
         return ('{} -> \n{}'
                 .format(short(self.name), self.product._short_repr()))
 
-    # __getstate__ and __setstate__ are needed to make this picklable
-
     def __getstate__(self):
         state = self.__dict__.copy()
         # _logger is not pickable, so we remove them and build
